pilas.actores.cooperativista

Package pilas :: Package actores :: Module cooperativista |
[hide private]
[frames] | no frames]

# Module cooperativista

source code

Classes | [hide private]
| Cooperativista Representa un Cooperativista que puede caminar y trabajar.
| Esperando Clase que define un comportamiento del actor Cooperativista.
| Caminando Clase que define un comportamiento del actor Cooperativista.
| DecirOk Clase que define un comportamiento del actor Cooperativista.

Variables | [hide private]
| VELOCIDAD = `4`
| __package__ = ``'``pilas.actores``'``